Enum x509_certificate::algorithm::DigestAlgorithm [−][src]
pub enum DigestAlgorithm {
Sha1,
Sha256,
Sha384,
Sha512,
}A hashing algorithm used for digesting data.
Instances can be converted to and from Oid via From/Into
implementations.
They can also be converted to and from The ASN.1 AlgorithmIdentifier, which is commonly used to represent them in X.509 certificates.
Instances can be converted into a digest::Context capable of computing
digests via From/Into.
Variants
SHA-1.
Corresponds to OID 1.3.14.3.2.26.
SHA-256.
Corresponds to OID 2.16.840.1.101.3.4.2.1.
SHA-384.
Corresponds to OID 2.16.840.1.101.3.4.2.2.
SHA-512.
Corresponds to OID 2.16.840.1.101.3.4.2.3.
Implementations
impl DigestAlgorithm[src]
impl DigestAlgorithm[src]Trait Implementations
impl Clone for DigestAlgorithm[src]
impl Clone for DigestAlgorithm[src]fn clone(&self) -> DigestAlgorithm[src]
fn clone(&self) -> DigestAlgorithm[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for DigestAlgorithm[src]
impl Debug for DigestAlgorithm[src]impl From<DigestAlgorithm> for AlgorithmIdentifier[src]
impl From<DigestAlgorithm> for AlgorithmIdentifier[src]fn from(alg: DigestAlgorithm) -> Self[src]
fn from(alg: DigestAlgorithm) -> Self[src]Performs the conversion.
impl Hash for DigestAlgorithm[src]
impl Hash for DigestAlgorithm[src]impl PartialEq<DigestAlgorithm> for DigestAlgorithm[src]
impl PartialEq<DigestAlgorithm> for DigestAlgorithm[src]impl TryFrom<&'_ AlgorithmIdentifier> for DigestAlgorithm[src]
impl TryFrom<&'_ AlgorithmIdentifier> for DigestAlgorithm[src]impl TryFrom<&'_ Oid<Bytes>> for DigestAlgorithm[src]
impl TryFrom<&'_ Oid<Bytes>> for DigestAlgorithm[src]impl Copy for DigestAlgorithm[src]
impl Eq for DigestAlgorithm[src]
impl StructuralEq for DigestAlgorithm[src]
impl StructuralPartialEq for DigestAlgorithm[src]